- occurrences
a binary (0/1) sample x species matrix, possibly including NAs.
- env
an optional sample x environmental variable matrix, for the known environmental predictors.
- traits
an optional species x trait matrix. Currently, it is only used for excluding
species interactions a priori.
- intercept
logical specifying whether to add a column for the species-level intercepts.
- n.latent
the number of latent variables to estimate.
- forbidden
a formula (or list of) defining which species interactions are not to be estimated. See details.
This constraint is cumulative with other constraints (mask.sp and exclude.prevalence).
- allowed
a formula (or list of) defining which species interactions are to be estimated. See details.
This constraint is cumulative with other constraints (mask.sp and exclude.prevalence).
- mask.sp
a scalar or a binary square species x species matrix defining which species interactions to exclude
(0) or include (1) a priori. If a scalar (0 or 1), 0 excludes all interactions, 1 allows all interactions.
If a matrix, species in the columns affect species in the rows, so, setting mask.sp[3, 8] <- 0
means that species #8 is assumed a priori to not affect species #3.
This constraint is cumulative with other constraints (forbidden and exclude.prevalence).
- exclude.prevalence
exclude species interactions which are caused by species
with prevalence equal or lower than this value. This constraint is cumulative with
other constraints (forbidden and mask.sp)
- options
a eicm.options object defining options for fitting. Usually not needed, use
forbidden, mask.sp and exclude.prevalence instead.
- initial.values
the starting values for all parameters. Used only for speeding up
fitting when there are previous estimates available.
- regularization
a two-element numeric vector defining the regularization lambdas used for
environmental coefficients and for species interactions respectively. See details.
- regularization.type
one of "lasso", "ridge" or "hybrid", defining the type of penalty to apply.
Type "hybrid" applies ridge penalty to environmental coefficients and LASSO to interaction coefficients.
- fast
a logical defining whether to do a fast - but less accurate - estimation, or a normal estimation.
- n.cores
the number of CPU cores to use in the L-BFGS-B optimization. This may be reduced to prevent
excessive memory usage.
- optim.method
the optimization function to use. Should be set to the default.
- optim.control
the optimization parameters to use. Should be set to the defaults.