Compute the (penalized) log-likelihood of the data matrix included in the EICM model, or the log-likelihood of a new occurrence data matrix given the model.
# S3 method for eicm
logLik(object, occurrences = NULL, allow.na = TRUE, ...)A logLik object.
a EICM model
the occurrence data matrix. If omitted, the data matrix used to fit the model is used.
logical. Allow NAs in the occurrence matrix? If no NAs exist, it's faster to set to FALSE.
additional argument(s) for methods.